==> ejc-salary-impl-3.0.0-20250116.073120-103-sources.jar: com/ejianc/business/report/bean/AccumulationSocialVWEntity.java <==
package com.ejianc.business.report.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人社保公积金信息浏览
 * 
 * @author generator
 * 
 */
 @TableName("vw_accumulation_social")
public class AccumulationSocialVWEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="department_id")
    private Long departmentId; // 部门id
    @TableField(value="department_code")
    private String departmentCode; // 部门编码
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="post_id")
    private Long postId; // 岗位id
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="job_level_name")
    private String jobLevelName; // 岗级
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex_name")
    private String sexName; // 性别
    @TableField(value="user_type_name")
    private String userTypeName; // 人员类别
    @TableField(value="mobile_phone")
    private String mobilePhone; // 手机号码
    @TableField(value="residency_type_name")
    private String residencyTypeName; // 派驻类别
    @TableField(value="education_name")
    private String educationName; // 最高学历
    @TableField(value="title_name")
    private String titleName; // 最高职称
    @TableField(value="social_department_code")
    private String socialDepartmentCode; // 社保缴纳单位编号
    @TableField(value="social_department_name")
    private String socialDepartmentName; // 社保缴纳单位
    @TableField(value="work_year")
    private String workYear; // 司龄
    @TableField(value="source_type")
    private String sourceType; // 人员库
    @TableField(value="bank_id")
    private Long bankId; // 开户行id
    @TableField(value="bank_code")
    private String bankCode; // 联行号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_address")
    private String bankAddress; // 银行地址
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_state")
    private Integer hrState; // 人员状态（1：启用，0：停用）
    @TableField(value="social_company_id")
    private Long socialCompanyId; // 社保承担公司id
    @TableField(value="social_company_code")
    private String socialCompanyCode; // 社保承担公司编号
    @TableField(value="company_name")
    private String companyName; // 社保承担公司
    @TableField(value="fund_payment_base")
    private BigDecimal fundPaymentBase; // 缴费基数
    @TableField(value="fund_start_time")
    private Date fundStartTime; // 公积金执行时间
    @TableField(value="person_money")
    private BigDecimal personMoney; // 个人公积金金额
    @TableField(value="company_money")
    private BigDecimal companyMoney; // 公司公积金金额
    @TableField(value="fund_change_reason")
    private String fundChangeReason; // 变更原因
    @TableField(value="social_payment_base")
    private BigDecimal socialPaymentBase; // 缴费基数
    @TableField(value="social_start_time")
    private Date socialStartTime; // 社保执行时间
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="social_change_reason")
    private String socialChangeReason; // 变更原因
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }
    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }
    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }
    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }
    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }
    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }
    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getBankId() {
        return bankId;
    }

    public void setBankId(Long bankId) {
        this.bankId = bankId;
    }
    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public Long getSocialCompanyId() {
        return socialCompanyId;
    }

    public void setSocialCompanyId(Long socialCompanyId) {
        this.socialCompanyId = socialCompanyId;
    }
    public String getSocialCompanyCode() {
        return socialCompanyCode;
    }

    public void setSocialCompanyCode(String socialCompanyCode) {
        this.socialCompanyCode = socialCompanyCode;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getFundPaymentBase() {
        return fundPaymentBase;
    }

    public void setFundPaymentBase(BigDecimal fundPaymentBase) {
        this.fundPaymentBase = fundPaymentBase;
    }
    public Date getFundStartTime() {
        return fundStartTime;
    }

    public void setFundStartTime(Date fundStartTime) {
        this.fundStartTime = fundStartTime;
    }
    public BigDecimal getPersonMoney() {
        return personMoney;
    }

    public void setPersonMoney(BigDecimal personMoney) {
        this.personMoney = personMoney;
    }
    public BigDecimal getCompanyMoney() {
        return companyMoney;
    }

    public void setCompanyMoney(BigDecimal companyMoney) {
        this.companyMoney = companyMoney;
    }
    public String getFundChangeReason() {
        return fundChangeReason;
    }

    public void setFundChangeReason(String fundChangeReason) {
        this.fundChangeReason = fundChangeReason;
    }
    public BigDecimal getSocialPaymentBase() {
        return socialPaymentBase;
    }

    public void setSocialPaymentBase(BigDecimal socialPaymentBase) {
        this.socialPaymentBase = socialPaymentBase;
    }
    public Date getSocialStartTime() {
        return socialStartTime;
    }

    public void setSocialStartTime(Date socialStartTime) {
        this.socialStartTime = socialStartTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getSocialChangeReason() {
        return socialChangeReason;
    }

    public void setSocialChangeReason(String socialChangeReason) {
        this.socialChangeReason = socialChangeReason;
    }
    
}

==> ejc-salary-impl-3.0.0-20250622.231317-149-sources.jar: com/ejianc/business/report/bean/AccumulationSocialVWEntity.java <==
package com.ejianc.business.report.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人社保公积金信息浏览
 * 
 * @author generator
 * 
 */
 @TableName("vw_accumulation_social")
public class AccumulationSocialVWEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="department_id")
    private Long departmentId; // 部门id
    @TableField(value="department_code")
    private String departmentCode; // 部门编码
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="post_id")
    private Long postId; // 岗位id
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="job_level_name")
    private String jobLevelName; // 岗级
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex_name")
    private String sexName; // 性别
    @TableField(value="user_type_name")
    private String userTypeName; // 人员类别
    @TableField(value="mobile_phone")
    private String mobilePhone; // 手机号码
    @TableField(value="residency_type_name")
    private String residencyTypeName; // 派驻类别
    @TableField(value="education_name")
    private String educationName; // 最高学历
    @TableField(value="title_name")
    private String titleName; // 最高职称
    @TableField(value="social_department_code")
    private String socialDepartmentCode; // 社保缴纳单位编号
    @TableField(value="social_department_name")
    private String socialDepartmentName; // 社保缴纳单位
    @TableField(value="work_year")
    private String workYear; // 司龄
    @TableField(value="source_type")
    private String sourceType; // 人员库
    @TableField(value="bank_id")
    private Long bankId; // 开户行id
    @TableField(value="bank_code")
    private String bankCode; // 联行号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_address")
    private String bankAddress; // 银行地址
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_state")
    private Integer hrState; // 人员状态（1：启用，0：停用）
    @TableField(value="social_company_id")
    private Long socialCompanyId; // 社保承担公司id
    @TableField(value="social_company_code")
    private String socialCompanyCode; // 社保承担公司编号
    @TableField(value="company_name")
    private String companyName; // 社保承担公司
    @TableField(value="fund_payment_base")
    private BigDecimal fundPaymentBase; // 缴费基数
    @TableField(value="fund_start_time")
    private Date fundStartTime; // 公积金执行时间
    @TableField(value="person_money")
    private BigDecimal personMoney; // 个人公积金金额
    @TableField(value="company_money")
    private BigDecimal companyMoney; // 公司公积金金额
    @TableField(value="fund_change_reason")
    private String fundChangeReason; // 变更原因
    @TableField(value="social_payment_base")
    private BigDecimal socialPaymentBase; // 缴费基数
    @TableField(value="social_start_time")
    private Date socialStartTime; // 社保执行时间
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="critical_illness_mny")
    private BigDecimal criticalIllnessMny; //
    @TableField(value="social_change_reason")
    private String socialChangeReason; // 变更原因


    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }
    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }
    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }
    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }
    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }
    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }
    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getBankId() {
        return bankId;
    }

    public void setBankId(Long bankId) {
        this.bankId = bankId;
    }
    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public Long getSocialCompanyId() {
        return socialCompanyId;
    }

    public void setSocialCompanyId(Long socialCompanyId) {
        this.socialCompanyId = socialCompanyId;
    }
    public String getSocialCompanyCode() {
        return socialCompanyCode;
    }

    public void setSocialCompanyCode(String socialCompanyCode) {
        this.socialCompanyCode = socialCompanyCode;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getFundPaymentBase() {
        return fundPaymentBase;
    }

    public void setFundPaymentBase(BigDecimal fundPaymentBase) {
        this.fundPaymentBase = fundPaymentBase;
    }
    public Date getFundStartTime() {
        return fundStartTime;
    }

    public void setFundStartTime(Date fundStartTime) {
        this.fundStartTime = fundStartTime;
    }
    public BigDecimal getPersonMoney() {
        return personMoney;
    }

    public void setPersonMoney(BigDecimal personMoney) {
        this.personMoney = personMoney;
    }
    public BigDecimal getCompanyMoney() {
        return companyMoney;
    }

    public void setCompanyMoney(BigDecimal companyMoney) {
        this.companyMoney = companyMoney;
    }
    public String getFundChangeReason() {
        return fundChangeReason;
    }

    public void setFundChangeReason(String fundChangeReason) {
        this.fundChangeReason = fundChangeReason;
    }
    public BigDecimal getSocialPaymentBase() {
        return socialPaymentBase;
    }

    public void setSocialPaymentBase(BigDecimal socialPaymentBase) {
        this.socialPaymentBase = socialPaymentBase;
    }
    public Date getSocialStartTime() {
        return socialStartTime;
    }

    public void setSocialStartTime(Date socialStartTime) {
        this.socialStartTime = socialStartTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getSocialChangeReason() {
        return socialChangeReason;
    }

    public void setSocialChangeReason(String socialChangeReason) {
        this.socialChangeReason = socialChangeReason;
    }
    
}
